@@ -4,15 +4,27 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 
+def delete_related(obj):
+    for related_object in obj._meta.related_objects:
+        related_manager = getattr(obj, related_object.get_accessor_name())
+        related_manager.all().delete()
+
+
 class FakeDeletionQuerySet(models.query.QuerySet):
+    # Fake deletion that also "deletes" related objects
     def delete(self):
         self.update(is_deleted=True)
+        for obj in self:
+            delete_related(obj)
 
 
 class Manager(models.Manager):
     """ Base manager with the following additions:
         - 'existing()' method that filters queryset by 'is_deleted=False'
+        - 'get_or_none()' method that returns object or None
+        - 'delete()' method that only sets 'is_deleted' field to True and also "deletes" related objects
     """
+
     def get_queryset(self):
         return FakeDeletionQuerySet(self.model, using=self._db)
 
@@ -25,6 +37,16 @@ class Manager(models.Manager):
         except self.model.DoesNotExist:
             return None
 
+    def delete(self):
+        self.update(is_deleted=True)
+        delete_related(self)
+
+    def save(self, *args, **kwargs):
+        if self.is_deleted:
+            delete_related(self)
+        super().save(*args, **kwargs)
+
+
 
 class Model(models.Model):
     """ Base model with the following additions:
@@ -32,6 +54,7 @@ class Model(models.Model):
         - created_at as object creation time;
         - updated_at as object last update time;
         - is_deleted as indicator that object is deleted or not;
+        - 'delete()' method that only sets 'is_deleted' field to True and also "deletes" related objects;
      """
 
     id = models.UUIDField(_('ID'), default=uuid.uuid4, primary_key=True, editable=False)
@@ -43,4 +66,3 @@ class Model(models.Model):
 
     class Meta:
         abstract = True
-
